@@ -1,16 +1,9 @@
 from django import forms
 from django.contrib import admin
 
-try:
-    from markitup.widgets import AdminMarkItUpWidget
-    wysiwyg_widget = AdminMarkItUpWidget
-except ImportError:
-    wysiwyg_widget = forms.Textarea
+from martor.widgets import AdminMartorWidget
 
-from marcus import models
-from marcus import actions
-from marcus import widgets
-from marcus import mixins
+from marcus import models, actions, widgets
 
 
 class TimedBooleanFilter(admin.FieldListFilter):
@@ -31,16 +24,6 @@ class TimedBooleanFilter(admin.FieldListFilter):
             }
 
 
-admin.site.register(
-    models.Category,
-    list_display=('title_ru', 'title_en', 'essential', 'parent', ))
-
-admin.site.register(
-    models.Tag,
-    list_display=('slug', 'title_ru', 'count_articles_ru', 'title_en', 'count_articles_en', ),
-    search_fields=('title_ru', 'title_en', ))
-
-
 class ArticleUploadForm(forms.ModelForm):
     upload = forms.FileField(widget=widgets.AdminImageWidget)
 
@@ -53,13 +36,14 @@ class ArticleUploadInlineAdmin(admin.TabularInline):
 class ArticleForm(forms.ModelForm):
     class Meta:
         model = models.Article
+        fields = '__all__'
         widgets = {
             'title_ru': forms.TextInput(attrs={'size': 80}),
-            'text_ru': wysiwyg_widget(attrs={'cols': 80, 'rows': 30}),
+            'text_ru': AdminMartorWidget(),
             'title_en': forms.TextInput(attrs={'size': 80}),
-            'text_en': wysiwyg_widget(attrs={'cols': 80, 'rows': 30}),
+            'text_en': AdminMartorWidget(),
         }
-    
+
     def clean(self):
         cleaned_data = super(ArticleForm, self).clean()
         title_ru = cleaned_data['title_ru']
@@ -69,23 +53,22 @@ class ArticleForm(forms.ModelForm):
 
         if (not title_ru and not text_ru) and (not title_en and not text_en):
             raise forms.ValidationError("Need to fill 'Title ru' or 'Title en'")
-        
+
         if not title_ru and text_ru:
             self._errors['title_ru'] = self.error_class(["Need to fill 'Title ru'"])
             del cleaned_data['title_ru']
-        
+
         if not title_en and text_en:
             self._errors['title_en'] = self.error_class(["Need to fill 'Title en'"])
             del cleaned_data['title_en']
-        
+
         return cleaned_data
 
 
-
-class ArticleAdmin(mixins.ArticleTextSizeAdminMixin, admin.ModelAdmin):
+class ArticleAdmin(admin.ModelAdmin):
     form = ArticleForm
     save_on_top = True
-    list_display = ('slug', 'title', 'text_size', 'is_published', )
+    list_display = ('slug', 'title', 'is_published', 'published')
     list_filter = (('published', TimedBooleanFilter), )
     search_fields = ('slug', 'title_ru', 'title_en', 'text_ru', 'text_en', 'categories__slug', 'categories__title_ru', 'categories__title_en', )
     ordering = ('-published', )
@@ -98,14 +81,10 @@ class ArticleAdmin(mixins.ArticleTextSizeAdminMixin, admin.ModelAdmin):
         return bool(obj.published)
     is_published.boolean = True
 
-admin.site.register(models.Article, ArticleAdmin)
-
 
 class ArticleUploadAdmin(admin.ModelAdmin):
     pass
 
-admin.site.register(models.ArticleUpload, ArticleUploadAdmin)
-
 
 class CommentAdmin(admin.ModelAdmin):
     save_on_top = True
@@ -115,7 +94,7 @@ class CommentAdmin(admin.ModelAdmin):
     ordering = ('-created', )
     select_related = ('article', )
     raw_id_fields = ('author', 'article', )
-    search_fields = ('article__slug', 'author__username', 'author__scipio_profile__openid', )
+    search_fields = ('article__slug', 'author__username', )
 
     def is_approved(self, obj):
         return bool(obj.approved)
@@ -126,4 +105,14 @@ class CommentAdmin(admin.ModelAdmin):
     created_str.admin_order_field = 'created'
     created_str.short_description = 'created'
 
+
+admin.site.register(
+    models.Category,
+    list_display=('title_ru', 'title_en', 'essential', 'parent', ))
+admin.site.register(
+    models.Tag,
+    list_display=('slug', 'title_ru', 'count_articles_ru', 'title_en', 'count_articles_en', ),
+    search_fields=('title_ru', 'title_en', ))
+admin.site.register(models.Article, ArticleAdmin)
+admin.site.register(models.ArticleUpload, ArticleUploadAdmin)
 admin.site.register(models.Comment, CommentAdmin)
