@@ -6,7 +6,7 @@ if hasattr(settings, 'MARCUS_SEARCH_FIELDS'):
     MARCUS_SEARCH_FIELDS = settings.MARCUS_SEARCH_FIELDS
 
 
-class MarcusQuerySet(models.query.QuerySet):
+class MarcusQuerySet(models.QuerySet):
     """Substitution the QuerySet
     """
     search_fields = MARCUS_SEARCH_FIELDS
@@ -21,12 +21,5 @@ class MarcusQuerySet(models.query.QuerySet):
 
 
 class MarcusManager(models.Manager):
-    def get_query_set(self):
-        model = models.get_model(self.model._meta.app_label, self.model._meta.object_name)
-        return MarcusQuerySet(model)
-
-    def __getattr__(self, attr, *args):
-        try:
-            return getattr(self.__class__, attr, *args)
-        except AttributeError:
-            return getattr(self.get_query_set(), attr, *args)
+    def get_queryset(self):
+        return MarcusQuerySet(self.model, using=self._db)
