@@ -1,24 +1,19 @@
-# coding: utf-8
 import json
-import scipio
-import pingdjack
 import datetime
-from scipio.forms import AuthForm
 
 from django import http
 from django.db.models import Q
 from django.utils import timezone
 from django.utils.safestring import mark_safe
 from django.core.paginator import Paginator, InvalidPage
-from django.core.urlresolvers import reverse
+from django.urls import reverse
 from django.views.decorators.http import require_POST
-from django.shortcuts import get_object_or_404, render, redirect
+from django.shortcuts import render, redirect
 from django.utils import translation
-from django.contrib import auth
-from django.contrib.auth.models import User
 from django.conf import settings
 
-from marcus import models, forms, antispam, utils
+from marcus import models, forms
+from marcus.utils import get_object_or_404
 
 
 def object_list(request, queryset, template_name, context):
@@ -37,8 +32,8 @@ def object_list(request, queryset, template_name, context):
 
 def superuser_required(func):
     def wrapper(request, *args, **kwargs):
-        if not request.user.is_authenticated() or not request.user.is_superuser:
-            return http.HttpResponseForbidden('Superuser required', mimetype='text/plain')
+        if not request.user.is_authenticated or not request.user.is_superuser:
+            return http.HttpResponseForbidden('Superuser required', content_type='text/plain')
         return func(request, *args, **kwargs)
     return wrapper
 
@@ -118,6 +113,7 @@ def tag(request, slug, language):
 
 def archive_index(request, language):
     translation.activate(language or 'ru')
+    settings.USE_TZ = False
     return render(request, 'marcus/archive-index.html', {
         'language': language,
         'months': sorted(models.Article.public.language(language).dates('published', 'month'), reverse=True),
@@ -149,7 +145,7 @@ def archive(request, year, month, language):
 
 def archive_short(request, year, language):
     args = [arg for arg in (year, language, ) if arg]
-    url = reverse('marcus-archive', args=args)
+    url = reverse('marcus:archive', args=args)
     return redirect(url)
 
 
@@ -170,19 +166,13 @@ def find_article(request, slug):
 
 
 def _process_new_comment(request, comment, language, check_login):
-    spam_status = antispam.conveyor.validate(request, comment=comment)
+    spam_status = 'unknown'  # TODO
     if spam_status == 'spam':
         comment.delete()
         return render(request, 'marcus/spam.html', {
             'text': comment.text,
             'admins': [e for n, e in settings.ADMINS],
         })
-    if check_login and not request.user.is_authenticated():
-        form = AuthForm(request.session, {'openid_identifier': request.POST['name']})
-        if form.is_valid():
-            comment = models.Translation(comment, language)
-            url = form.auth_redirect(request, target=comment.get_absolute_url(), data={'acquire': str(comment.pk)})
-            return redirect(url)
     comment.spam_status = spam_status
     if spam_status == 'clean':
         comment.approved = timezone.now()
@@ -194,13 +184,15 @@ def _process_new_comment(request, comment, language, check_login):
 
 def article_short(request, year, slug, language):
     obj = get_object_or_404(models.Article, published__year=year, slug=slug)
-    args = [i for i in year, obj.published.month, obj.published.day, slug, language if i]
-    url = reverse('marcus-article', args=args)
+    args = [i for i in (year, obj.published.month, obj.published.day, slug, language) if i]
+    url = reverse('marcus:article', args=args)
     return redirect(url)
 
 
 def article(request, year, month, day, slug, language):
-    obj = get_object_or_404(models.Article, published__year=year, published__month=month, published__day=day, slug=slug)
+    obj = get_object_or_404(
+        models.Article, published__year=year, published__month=month, published__day=day, slug=slug
+    )
     guest_name = request.session.get('guest_name', '')
     guest_email = request.session.get('guest_email', '')
     translation.activate(language or obj.only_language() or 'ru')
@@ -209,14 +201,14 @@ def article(request, year, month, day, slug, language):
         if form.is_valid():
             request.session['guest_name'] = form.cleaned_data.get('name', '')
             request.session['guest_email'] = form.cleaned_data.get('xemail', '')
-            form.cleaned_data['text'] = form.cleaned_data['text'].replace('script', u'sсript')
+            form.cleaned_data['text'] = form.cleaned_data['text'].replace('script', 'sсript')
             comment = form.save()
             return _process_new_comment(request, comment, language, True)
     else:
         form = forms.CommentForm(article=obj, language=language)
 
     comments = models.Comment.common.language(language)\
-        .select_related('author', 'author__scipio_profile', 'article')\
+        .select_related('author', 'article')\
         .filter(article=obj, type="comment")\
         .filter(Q(guest_name=guest_name) | ~Q(approved=None))\
         .order_by('created', 'approved')
@@ -230,12 +222,6 @@ def article(request, year, month, day, slug, language):
         if 'unapproved' in request.session:
             del request.session['unapproved']
 
-    retweet_url = u'http://twitter.com/home/?status={title}%20{url}%20{suffix}'.format(
-        title=obj.title(),
-        url=utils.absolute_url(utils.iurl(reverse('marcus-article-short', args=[obj.published.year, obj.slug, ]), language)),
-        suffix=settings.MARCUS_RETWEET_SUFFIX.replace('@', '%40')
-    )
-
     keywords = [tag.title(language) for tag in obj.tags.all()] +\
         [category.title(language) for category in obj.categories.all()]
 
@@ -248,7 +234,6 @@ def article(request, year, month, day, slug, language):
         'language': language,
         'guest_name': guest_name,
         'guest_email': guest_email,
-        'retweet_url': retweet_url,
         'meta_keywords': ", ".join(keywords),
         'meta_description': (obj.intro(language) or "").replace('"', "'"),
     })
@@ -265,32 +250,12 @@ def draft(request, pk, language):
     })
 
 
-def acquire_comment(sender, user, acquire=None, language=None, **kwargs):
-    if acquire is None:
-        return
-    try:
-        auth.login(sender, user)
-        comment = models.Comment.objects.get(pk=acquire)
-        comment.author = user
-        comment.save()
-        _process_new_comment(sender, comment, language, False)
-    except models.Comment.DoesNotExist:
-        pass
-scipio.signals.authenticated.connect(acquire_comment)
-
-
 @superuser_required
 @require_POST
 def approve_comment(request, id):
     comment = get_object_or_404(models.Comment, pk=id)
-    antispam.conveyor.submit_ham(comment.spam_status, comment=comment)
     comment.approved = timezone.now()
     comment.save()
-    if not comment.by_guest():
-        scipio_profile = comment.author.scipio_profile
-        if scipio_profile.spamer is None:
-            scipio_profile.spamer = False
-            scipio_profile.save()
     return redirect(spam_queue)
 
 
@@ -298,12 +263,6 @@ def approve_comment(request, id):
 @require_POST
 def spam_comment(request, id):
     comment = get_object_or_404(models.Comment, pk=id)
-    if not comment.by_guest():
-        scipio_profile = comment.author.scipio_profile
-        if scipio_profile.spamer is None:
-            scipio_profile.spamer = True
-            scipio_profile.save()
-    antispam.conveyor.submit_spam(comment=comment)
     comment.delete()
     return redirect(comment.article)
 
@@ -334,54 +293,35 @@ def comment_preview(request):
     )
 
 
-def handle_pingback(sender, source_url, view, args, author, excerpt, **kwargs):
-    if view != article:
-        raise pingdjack.UnpingableTarget
-    a = models.Article.objects.get(slug=args[3])
-    if a.comments.filter(type='pingback', guest_url=source_url):
-        raise pingdjack.DuplicatePing
-    a.comments.create(
-        type='pingback',
-        text=excerpt,
-        author=User.objects.get(username='marcus_guest'),
-        guest_name=author,
-        guest_url=source_url,
-        ip=get_ip(sender),
-        language=a.comment_language(args[4]),
-        approved=timezone.now(),
-    )
-pingdjack.received.connect(handle_pingback)
-
-
 def article_upload_image_preview(request, object_id):
     max_width = 300
     image_path = get_object_or_404(models.ArticleUpload, pk=object_id).upload.path
 
-    import StringIO
+    import io
     try:
         from PIL import Image
     except ImportError:
         import Image
     try:
         image = Image.open(image_path.encode('utf-8'))
-    except:
-        return http.HttpResponse("Not a image", mimetype="text/html")
+    except Exception:
+        return http.HttpResponse("Not a image", content_type="text/html")
 
-    buffer = StringIO.StringIO()
+    buffer = io.StringIO()
     max_width = max_width if max_width < image.size[0] else image.size[0]
     height = int((float(image.size[1]) * float(max_width / float(image.size[0]))))
     image.resize((max_width, height), Image.ANTIALIAS).save(buffer, "PNG")
-    return http.HttpResponse(buffer.getvalue(), mimetype="image/png")
+    return http.HttpResponse(buffer.getvalue(), content_type="image/png")
 
 
 def search(request, language):
     SEARCH_LANGUAGES = (
-        (None, translation.ugettext_lazy(u'All')),
-        ('en', translation.ugettext_lazy(u'English')),
+        (None, translation.ugettext_lazy('All')),
+        ('en', translation.ugettext_lazy('English')),
     )
     search_query = request.GET.get('s', '')
     search_language = request.GET.get('l', None)
-    if search_language not in dict(SEARCH_LANGUAGES).keys():
+    if search_language not in list(dict(SEARCH_LANGUAGES).keys()):
         search_language = None
 
     language = search_language
@@ -415,7 +355,7 @@ def article_comments_unsubscribe(request, article_id, token, language):
             break
     else:
         return http.HttpResponseForbidden(
-            'Token is failed or expired!', mimetype='text/plain')
+            'Token is failed or expired!', content_type='text/plain')
 
     return render(request, 'marcus/unsubscribe.html', {
         'article_link': mark_safe(article.link(language)),
